try_rules_via_daemon

Function try_rules_via_daemon 

pub fn try_rules_via_daemon(
    root: &Path,
    filter_ids: Option<&HashSet<String>>,
    filter_rule: Option<&str>,
    engine: Option<&str>,
    filter_files: Option<&[String]>,
) -> Option<Vec<Issue>>
Try to run rules via the daemon’s diagnostics cache.

Returns Some(issues) if the daemon is running and successfully returned cached results. Returns None if the daemon is unavailable or returns an error, in which case the caller should fall back to local evaluation.

engine filters which engine’s results to return: Some("syntax"), Some("fact"), Some("native"), or None for all engines.

This avoids a circular-dependency between normalize-rules and the main normalize crate by talking to the daemon socket directly rather than through DaemonClient.