pub struct RuleEntry {
pub id: String,
pub rule_type: String,
pub severity: String,
pub source: String,
pub message: String,
pub enabled: bool,
pub tags: Vec<String>,
pub recommended: bool,
}Expand description
A single rule entry in a list report.
Fields
id: Stringrule_type: Stringseverity: Stringsource: Stringmessage: Stringenabled: boolrecommended: boolTrait Implementations
Sourceimpl JsonSchema for RuleEntry
impl JsonSchema for RuleEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RuleEntry
impl RefUnwindSafe for RuleEntry
impl Send for RuleEntry
impl Sync for RuleEntry
impl Unpin for RuleEntry
impl UnsafeUnpin for RuleEntry
impl UnwindSafe for RuleEntry