pub struct RulesListReport {
pub rules: Vec<RuleEntry>,
pub total: usize,
pub syntax_count: usize,
pub fact_count: usize,
pub native_count: usize,
pub disabled_count: usize,
}Expand description
Report returned by normalize rules list.
Fields
rules: Vec<RuleEntry>total: usizesyntax_count: usizefact_count: usizenative_count: usizedisabled_count: usizeTrait Implementations
Sourceimpl Clone for RulesListReport
impl Clone for RulesListReport
Sourcefn clone(&self) -> RulesListReport
fn clone(&self) -> RulesListReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RulesListReport
impl Debug for RulesListReport
Sourceimpl JsonSchema for RulesListReport
impl JsonSchema for RulesListReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl OutputFormatter for RulesListReport
impl OutputFormatter for RulesListReport
Sourcefn format_text(&self) -> String
fn format_text(&self) -> String
Format as minimal text (LLM-optimized, default).
Sourcefn format_pretty(&self) -> String
fn format_pretty(&self) -> String
Format as pretty text (human-friendly with colors).
Default implementation falls back to format_text().